@@ -93,60 +93,37 @@ setMethod(
 setMethod(
     f = "coef",
     signature = 'ExploratoryClass',
-    definition = function(object, rotate = '', Target = NULL, allpars = TRUE, digits = 3, 
-                          verbose = TRUE, ...){         
+    definition = function(object, rotate = '', Target = NULL, digits = 3, ...){         
         K <- object@K
         J <- length(K)
         nfact <- ncol(object@F)
         a <- matrix(0, J, nfact)
         for(i in 1:J)
             a[i, ] <- ExtractLambdas(object@pars[[i]])        
-        A <- sqrt(apply(a^2,1,sum))                        
         if (ncol(a) > 1){ 
             rotname <- ifelse(rotate == '', object@rotate, rotate)
-            so <- summary(object, rotate = rotate, Target = Target, verbose = FALSE, ...)             
-            a <- rotateLambdas(so)            
+            so <- summary(object, rotate=rotate, Target=Target, verbose=FALSE, digits=digits, ...)             
+            a <- rotateLambdas(so) * 1.702/object@pars[[1]]@D
             for(i in 1:J)
-                object@pars[[i]]@par[1:nfact] <- a[i, ] 
+                object@pars[[i]]@par[1:nfact] <- a[i, ]            
+            object@pars[[J + 1]]@par[-c(1:nfact)] <- so$fcor[lower.tri(so$fcor, TRUE)]            
         }   
-        rownames(a) <- colnames(object@data)
-        if(nfact > 1){
-            a <- round(cbind(a, A), digits)
-            colnames(a) <- c(paste('a', 1:nfact, sep=''), 'MV_disc')
-        } else {
-            a <- round(a, digits)
-            colnames(a) <- paste('a', 1:nfact, sep='')
-        }
         allPars <- list()        
-        if(allpars){
-            if(length(object@pars[[1]]@SEpar) > 0){
-                for(i in 1:(J+1)){
-                    allPars[[i]] <- round(matrix(c(object@pars[[i]]@par, object@pars[[i]]@SEpar), 
-                                                 2, byrow = TRUE), digits)
-                    rownames(allPars[[i]]) <- c('pars', 'SE')
-                    colnames(allPars[[i]]) <- names(object@pars[[i]]@parnum)
-                } 
-            } else {
-                for(i in 1:(J+1)){
-                    allPars[[i]] <- round(object@pars[[i]]@par, digits)
-                    names(allPars[[i]]) <- names(object@pars[[i]]@parnum)
-                }
-            }                  
-            names(allPars) <- c(rownames(a), 'GroupPars')
-        }        
-        ret <- if(allpars) return(allPars) else a
-        if(nfact > 1 && verbose) cat('\nRotation:', rotname, '\n\n')
-        fcor <- 1
-        if (ncol(a) > 1 && !allpars){
-            fcor <- so$fcor
-            colnames(fcor) <- rownames(fcor) <- paste('F', 1:nfact, sep='')            
-            if(verbose) {
-                print(round(fcor, 3))
-                cat('\n')
+        if(length(object@pars[[1]]@SEpar) > 0){
+            for(i in 1:(J+1)){
+                allPars[[i]] <- round(matrix(c(object@pars[[i]]@par, object@pars[[i]]@SEpar), 
+                                             2, byrow = TRUE), digits)
+                rownames(allPars[[i]]) <- c('pars', 'SE')
+                colnames(allPars[[i]]) <- names(object@pars[[i]]@parnum)
+            } 
+        } else {
+            for(i in 1:(J+1)){
+                allPars[[i]] <- round(object@pars[[i]]@par, digits)
+                names(allPars[[i]]) <- names(object@pars[[i]]@parnum)
             }
-        }
-        if(verbose) print(ret)        
-        return(invisible(list(ret, fcor)))
+        }                  
+        names(allPars) <- c(colnames(object@data), 'GroupPars')
+        return(allPars) 
     }
 )
 
@@ -219,8 +196,6 @@ setMethod(
             if(verbose) cat("LD matrix (lower triangle) and standardized values:\n\n")    
             res <- round(res,digits)
             return(res)	
-            res <- round(res,digits)
-            return(res)
         } 
         if(restype == 'exp'){	
             r <- object@tabdata[ ,ncol(object@tabdata)]
@@ -247,7 +222,7 @@ setMethod(
     definition = function(x, y, type = 'info', npts = 50, theta_angle = 45, 
                           rot = list(xaxis = -70, yaxis = 30, zaxis = 10), ...)
     {           
-        if (!type %in% c('info','infocontour')) stop(type, " is not a valid plot type.")
+        if (!type %in% c('info','infocontour', 'SE')) stop(type, " is not a valid plot type.")
         if (any(theta_angle > 90 | theta_angle < 0)) 
             stop('Improper angle specifed. Must be between 0 and 90.')
         if(length(theta_angle) > 1) type = 'infoangle'
@@ -261,16 +236,17 @@ setMethod(
         prodlist <- attr(x@pars, 'prodlist')
         if(length(prodlist) > 0)        
             ThetaFull <- prodterms(Theta,prodlist)        
-        info <- 0        
+        info <- 0            
         for(l in 1:length(theta_angle)){
             ta <- theta_angle[l]
             if(nfact == 2) ta <- c(theta_angle[l], 90 - theta_angle[l])
             for(i in 1:J)
                 info <- info + iteminfo(x=x@pars[[i]], Theta=ThetaFull, degrees=ta)            
         }
-        plt <- data.frame(cbind(info,Theta))
+        plt <- data.frame(cbind(info,Theta))         
         if(nfact == 2){						
             colnames(plt) <- c("info", "Theta1", "Theta2")			
+            plt$SE <- 1 / sqrt(plt$info)
             if(type == 'infocontour')												
                 return(contourplot(info ~ Theta1 * Theta2, data = plt, 
                                    main = paste("Test Information Contour"), xlab = expression(theta[1]), 
@@ -283,13 +259,21 @@ setMethod(
                 symbols(plt[,2], plt[,3], circles = sqrt(plt[,1]/pi), inches = .35, fg='white', bg='blue', 
                         xlab = expression(theta[1]), ylab = expression(theta[2]), 
                         main = 'Information across different angles')
+            if(type == 'SE')                
+                return(wireframe(SE ~ Theta1 + Theta2, data = plt, main = "Test Standard Errors", 
+                                 zlab=expression(SE(theta)), xlab=expression(theta[1]), ylab=expression(theta[2]), 
+                                 scales = list(arrows = FALSE), screen = rot, colorkey = TRUE, drape = TRUE))            
         } else {
             colnames(plt) <- c("info", "Theta")
+            plt$SE <- 1 / sqrt(plt$info)
             if(type == 'info')
                 return(xyplot(info~Theta, plt, type='l',main = 'Test Information', 
                               xlab = expression(theta), ylab=expression(I(theta))))				
             if(type == 'infocontour') 
                 cat('No \'contour\' plots for 1-dimensional models\n')
+            if(type == 'SE')                
+                xyplot(SE~Theta, plt, type='l',main = 'Test Standard Errors', 
+                       xlab = expression(theta), ylab=expression(SE(theta)))
         }		
     }		
 )	
