@@ -26,6 +26,15 @@
 #' \code{anova} function, where a Chi-squared difference test and AIC/BIC
 #' difference values are displayed.
 #' 
+#' @section Convergence:
+#' 
+#' The MHRM algorithm often is more stable than the EM counterpart in \code{mirt} but 
+#' convergence of the algorithm should be interpreted with caution. When the number of iterations 
+#' grows very high (e.g., greater than 1500) or when \code{Max Change = .2500} values are repeatedly printed
+#' to the console too often (indicating that the parameters were being constrained since they are naturally 
+#' moving in steps greater than 0.25) then the model may either be ill defined or have a 
+#' very flat likelihood surface, and genuine maximum likelihood parameter estimates may be difficult to find. 
+#' 
 #' @section Confirmatory IRT:
 #' 
 #' Specification of the confirmatory item factor analysis model follows many of
@@ -38,8 +47,7 @@
 #' 
 #' Specifying a number as the second input to confmirt an exploratory IRT model is estimated and 
 #' can be viewed as a stochastic analogue of \code{mirt}, with much of the same behaviour and 
-#' specifications. 
-#' Rotation and target matrix options will be used in this subroutine and will be
+#' specifications. Rotation and target matrix options will be used in this subroutine and will be
 #' passed to the returned object for use in generic functions such as \code{summary()} and 
 #' \code{fscores}. Again, factor means and variances are fixed to ensure proper identification. See
 #' \code{\link{mirt}} for more details.
@@ -65,7 +73,6 @@
 #' \code{abs(printvalue)}. The default (NULL) prints all response patterns
 #' @param verbose logical; display iteration history during estimation?
 #' @param draws the number of Monte Carlo draws to estimate the log-likelihood
-#' @param allpars logical; print all the item parameters instead of just the slopes?
 #' @param restype type of residuals to be displayed. Can be either \code{'LD'}
 #' for a local dependence matrix (Chen & Thissen, 1997) or \code{'exp'} for the
 #' expected values for the frequencies of every response pattern
@@ -89,10 +96,9 @@
 #' @param parprior a list of user declared prior item probabilities. To see how to define the
 #' parameters correctly use \code{pars = 'values'} initially to see how the parameters are labeled.
 #' Can define either normal (normally for slopes and intercepts) or beta (for guessing and upper bounds) prior
-#' probabilities. Note that for upper bounds the value used in the prior is 1 - u so that the lower and upper 
-#' bounds can function the same. To specify a prior the form is c('priortype', ...), where normal priors 
-#' are \code{parprior = list(c(parnumber, 'norm', mean, sd))} and betas are 
-#' \code{parprior = list(c(parnumber, 'beta', alpha, beta))}. 
+#' probabilities. To specify a prior the form is c('priortype', ...), where normal priors 
+#' are \code{parprior = list(c(parnumbers, 'norm', mean, sd))} and betas are 
+#' \code{parprior = list(c(parnumbers, 'beta', alpha, beta))}
 #' @param pars a data.frame with the structure of how the starting values, parameter numbers, and estimation
 #' logical values are defined. The user may observe how the model defines the values by using \code{pars = 
 #' 'values'}, and this object can in turn be modified and input back into the estimation with \code{pars = 
@@ -107,14 +113,16 @@
 #' @param suppress a numeric value indicating which factor
 #' loadings should be suppressed. Typical values are around .3 in most
 #' statistical software. Default is 0 for no suppression
+#' @param D a numeric value used to adjust the logistic metric to be more similar to a normal
+#' cumulative density curve. Default is 1.702
 #' @param technical list specifying subtle parameters that can be adjusted. These 
 #' values are 
 #' @param df.p logical; print the degrees of freedom and p-values?
 #' @param x an object of class \code{mirt} to be plotted or printed
 #' @param y an unused variable to be ignored
-#' @param type type of plot to view; can be \code{'curve'} for the total test
-#' score as a function of two dimensions, or \code{'info'} to show the test
-#' information function for two dimensions
+#' @param type type of plot to view; can be \code{'info'} to show the test
+#' information function, \code{'infocontour'} for the test information contours, 
+#' or \code{'SE'} for the test standard error function
 #' @param theta_angle numeric values ranging from 0 to 90 used in \code{plot}. If a vector is 
 #' used then a bubble plot is created with the summed information across the angles specified 
 #' (e.g., \code{theta_angle = seq(0, 90, by=10)})
@@ -160,12 +168,12 @@
 #' @usage 
 #' confmirt(data, model, itemtype = NULL, guess = 0, upper = 1, pars = NULL, 
 #' constrain = NULL, parprior = NULL, grsm.block = NULL, verbose = TRUE, 
-#' draws = 2000, debug = FALSE, rotate = 'varimax', Target = NULL, 
+#' draws = 2000, debug = FALSE, rotate = 'varimax', Target = NULL, D = 1.702, 
 #' technical = list(),  ...)
 #' 
 #' \S4method{summary}{ConfirmatoryClass}(object, suppress = 0, digits = 3, verbose = TRUE, ...)
 #' 
-#' \S4method{coef}{ConfirmatoryClass}(object, allpars = TRUE, digits = 3, verbose = TRUE, ...)
+#' \S4method{coef}{ConfirmatoryClass}(object, digits = 3, ...)
 #' 
 #' \S4method{anova}{ConfirmatoryClass}(object, object2)
 #' 
@@ -268,12 +276,12 @@
 confmirt <- function(data, model, itemtype = NULL, guess = 0, upper = 1, pars = NULL, 
                      constrain = NULL, parprior = NULL, grsm.block = NULL, verbose = TRUE, 
                      draws = 2000, debug = FALSE, rotate = 'varimax', Target = NULL, 
-                     technical = list(),  ...)
+                     D = 1.702, technical = list(),  ...)
 {   
     if(debug == 'Main') browser()
     Call <- match.call()    
     mod <- ESTIMATION(data=data, model=model, group = rep('all', nrow(data)), itemtype=itemtype, 
-                      guess=guess, upper=upper, grsm.block=grsm.block,
+                      guess=guess, upper=upper, grsm.block=grsm.block, D=D,
                       pars=pars, constrain=constrain, parprior=parprior, verbose=verbose, 
                       draws=draws, debug=debug, technical = list(),  ...)
     if(is(mod, 'ExploratoryClass') || is(mod, 'ConfirmatoryClass'))
