@@ -1,7 +1,8 @@
 #' Person fit statistics
 #' 
 #' \code{personfit} calculates the Zh values from Drasgow, Levine and Williams (1985) for 
-#' unidimensional and multidimensional models, as well as infit and outfit statistics. 
+#' unidimensional and multidimensional models. For Rasch models infit and outfit statistics are 
+#' also produced.
 #' The returned object is a \code{data.frame}
 #' consisting either of the tabulated data or full data with the statistics appended to the last 
 #' columns. 
@@ -10,7 +11,9 @@
 #' @aliases personfit
 #' @param x a computed model object of class \code{ExploratoryClass}, \code{ConfirmatoryClass}, or 
 #' \code{MultipleGroupClass}
-#' @param degrees the degrees angle to be passed to the \code{\link{iteminfo}} function
+#' @param method type of factor score estimation method. Can be expected
+#' a-posteriori (\code{"EAP"}), Bayes modal (\code{"MAP"}), weighted likelihood estimation 
+#' (\code{"WLE"}), or maximum likelihood (\code{"ML"}) 
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #' @keywords person fit
 #' @export personfit
@@ -33,7 +36,7 @@
 #'
 #' #make some data
 #' set.seed(1234)
-#' a <- matrix(rnorm(20),ncol=1)
+#' a <- matrix(rlnorm(20),ncol=1)
 #' d <- matrix(rnorm(20),ncol=1)
 #' items <- rep('dich', 20)
 #' data <- simdata(a,d, 2000, items)
@@ -44,16 +47,16 @@
 #' 
 #'   }
 #' 
-personfit <- function(x, degrees = NULL){        
+personfit <- function(x, method = 'EAP'){        
     if(is(x, 'MultipleGroupClass')){
         ret <- list()   
         for(g in 1:length(x@cmods))
-            ret[[g]] <- personfit(x@cmods[[g]], degrees=degrees)
+            ret[[g]] <- personfit(x@cmods[[g]])
         names(ret) <- names(x@cmods)
         return(ret)
     }
     full.scores <- TRUE
-    sc <- fscores(x, verbose = FALSE, full.scores=full.scores) 
+    sc <- fscores(x, verbose = FALSE, full.scores=full.scores, method=method) 
     J <- ncol(x@data)
     itemloc <- x@itemloc
     pars <- x@pars
@@ -67,6 +70,14 @@ personfit <- function(x, degrees = NULL){
         fulldata <- fulldata[,-ncol(fulldata)]
         Theta <- sc[ ,ncol(sc):(ncol(sc) - nfact + 1) - nfact, drop = FALSE]        
     }
+    if(method %in% c('ML', 'WLE')){
+        for(i in 1:ncol(Theta)){
+            tmp <- Theta[,i]
+            tmp[tmp %in% c(-Inf, Inf)] <- NA
+            Theta[Theta[,i] == Inf, i] <- max(tmp, na.rm=TRUE) + .1
+            Theta[Theta[,i] == -Inf, i] <- min(tmp, na.rm=TRUE) - .1
+        }       
+    }
     N <- nrow(Theta)
     itemtrace <- matrix(0, ncol=ncol(fulldata), nrow=N)        
     for (i in 1:J)
@@ -89,21 +100,26 @@ personfit <- function(x, degrees = NULL){
         }
         Zh[n] <- (LL[n] - mu) / sqrt(sigma2)
     }               
-    V <- Z <- info <- matrix(0, ncol=J, nrow=N)        
-    if(is.null(degrees))
-        if(nfact > 1) degrees <- rep(90/nfact, nfact)            
-    for (i in 1:J){
-        P <- ProbTrace(x=pars[[i]], Theta=Theta)
-        dat <- fulldata[ ,itemloc[i]:(itemloc[i+1] - 1)]            
-        item <- extract.item(x, i)
-        info[,i] <- iteminfo(item, Theta, degrees=degrees)
-        Z[ ,i] <- rowSums(dat - dat * P) / sqrt(info[,i])                         
+    if(all(x@itemtype %in% 'Rasch')){
+        V <- resid2 <- info <- matrix(0, ncol=J, nrow=N)  
+        K <- x@K
+        for (i in 1:J){            
+            P <- ProbTrace(x=pars[[i]], Theta=Theta)
+            Emat <- matrix(0:(K[i]-1), nrow(P), ncol(P), byrow = TRUE)            
+            dat <- fulldata[ ,itemloc[i]:(itemloc[i+1] - 1)]               
+            item <- extract.item(x, i)
+            info[,i] <- iteminfo(item, Theta)
+            resid2[ ,i] <- rowSums((dat*Emat - Emat * P))^2 
+        }
+        if(!is.null(attr(x, 'inoutfitreturn'))) return(list(resid2=resid2, info=info))
+        outfit <- rowSums(resid2/info) / J
+        infit <- rowSums(resid2) / rowSums(info)    
+        if(full.scores) ret <- data.frame(x@data, outfit=outfit, infit=infit, Zh=Zh)
+        else ret <- data.frame(x@tabdata, outfit=outfit, infit=infit, Zh=Zh)
+    } else {
+        if(full.scores) ret <- data.frame(x@data, Zh=Zh)
+        else ret <- data.frame(x@tabdata, Zh=Zh)        
     }
-    if(!is.null(attr(x, 'inoutfitreturn'))) return(list(Z=Z, info=info))
-    outfit <- rowSums(Z^2) / J
-    infit <- rowSums(Z^2 * info) / rowSums(info)    
-    if(full.scores) ret <- data.frame(x@data, outfit=outfit, infit=infit, Zh=Zh)
-    else ret <- data.frame(x@tabdata, outfit=outfit, infit=infit, Zh=Zh)        
     return(ret)
 }
     
